# py_nui_exe

## Overview
A tool to assist in generating Nuitka commands, one of the Python build libraries. 
Users can generate commands by setting and selecting necessary settings on the GUI. 
The command content is sent to the prompt and executed up to Nuitka.

Archived  
My Repsitory(https://github.com/KMASTERgit/Build_Python_To_exe_for_Clung)  
That repository can not pip install.
So rebaked that pip install can be done.

## Caution
Self development and may contain defects. Please be aware of this.

## Warning
This application is not official.
Unofficial app！！

## Installation
1. Install Nuitka according to the official documentation.
   Reference: [WebSite](https://nuitka.net/user-documentation/user-manual.html)  or  [Github](https://github.com/Nuitka/Nuitka?tab=readme-ov-file)
2. For Command
>pip install git+https://github.com/KMASTERgit/py_nui_exe.git
3. For Command
>py-nui-exe
4. Wake up py-nui-exe → select the Python file to be converted to exe and select the necessary commands, then execute Nuitka by clicking "Send to prompt".

## Usage
Please refer to the attached video.

## Contributing
Feel free to contribute as long as you don't include malicious files such as viruses.

## License
MIT License

=======JAPANESE===========

# py_nui_exe

## 概要
Pythonのビルドライブラリの1つであるNuitkaのコマンド生成を補助するツールです。
GUI上で必要な設定・選択を行い、コマンドを生成できます。
生成されたコマンドはプロンプトに送信され、Nuitkaが実行されます。

別リポジトリ(https://github.com/KMASTERgit/Build_Python_To_exe_for_Clung)を  
pipでインストールできるようにしたversionです。


## 注意
個人開発のため、不具合が含まれる可能性があります。ご了承ください。

## 警告
非公式アプリケーションです。

## インストール
1. Nuitkaを公式ドキュメントに従いインストールしてください。
  参考: [WebSite](https://nuitka.net/user-documentation/user-manual.html)  or  [Github](https://github.com/Nuitka/Nuitka?tab=readme-ov-file)
2. コマンドプロンプトで
>pip install git+https://github.com/KMASTERgit/py_nui_exe.git
3. コマンドプロンプトで
>py-nui-exe
3. アプリが起動するので、exe化したいPythonファイルを選択し、必要なコマンドを選択後、"プロンプト送信"をクリックするとNuitkaが実行されます。

## 使い方
添付動画をご覧ください。

## 貢献
ウイルスなどの悪意のあるファイルを含まない限り、自由に貢献してください。

## ライセンス
MITライセンス
